@@ -102,17 +102,25 @@ WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
  */
 
 /* Strange base64 encoding set used by the CD index */
-static unsigned char oddity_64[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789._-";
+static unsigned char oddity_64[] =
+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789._-";
 
 int
-cd_basis_encode64(unsigned char *outbuffer, unsigned char *inbuffer, int inlen, int outlen, unsigned char *basis)
+cd_basis_encode64(unsigned char *outbuffer, unsigned char *inbuffer,
+		  int inlen, int outlen, unsigned char *basis)
 {
    unsigned long outdex = 0, s_count = inlen, index;
  
    for (index = 0; s_count; inbuffer += 3) {   
       outbuffer[outdex++] = basis[inbuffer[0] >> 2];
-      outbuffer[outdex++] = basis[((inbuffer[0] << 4) + (--s_count ? (inbuffer[1] >> 4) : 0)) & 0x3f];
-      outbuffer[outdex++] = s_count ? basis[((inbuffer[1] << 2) + (--s_count ? (inbuffer[2] >> 6) : 0)) & 0x3f] : basis[64];
+      outbuffer[outdex++] =
+	basis[((inbuffer[0] << 4) +
+	       (--s_count ? (inbuffer[1] >> 4) : 0)) & 0x3f];
+      outbuffer[outdex++] =
+	s_count ?
+	basis[((inbuffer[1] << 2) +
+	       (--s_count ? (inbuffer[2] >> 6) : 0)) & 0x3f] :
+	basis[64];
       outbuffer[outdex++] = s_count ? basis[inbuffer[2] & 0x3f] : basis[64];
       if (s_count) s_count--;          
       if ((++index) == 15) {
@@ -125,15 +133,8 @@ cd_basis_encode64(unsigned char *outbuffer, unsigned char *inbuffer, int inlen,
 }
 
 int
-#if __STDC__
-cdindex_encode64(unsigned char *outbuffer, unsigned char *inbuffer, int inlen, int outlen)
-#else
-cdindex_encode64(outbuffer, inbuffer, inlen, outlen)
-   unsigned char *outbuffer;
-   unsigned char *inbuffer;
-   int inlen;
-   int outlen;
-#endif
+cdindex_encode64(unsigned char *outbuffer, unsigned char *inbuffer,
+		 int inlen, int outlen)
 {
    return cd_basis_encode64(outbuffer, inbuffer, inlen, outlen, oddity_64);
 }
