@@ -306,6 +306,17 @@ cd_poll(int cd_desc, struct disc_status *status)
   struct CDAUDIO_SUBCHANNEL_DATA cdsc_data;
 #endif
 
+#ifdef CDAUDIO_DISC_STATUS
+  {
+    int ret = ioctl (cd_desc, CDAUDIO_DISC_STATUS, NULL);
+    if (ret != CDS_AUDIO && ret != CDS_MIXED)
+      {
+	status->status_present = 0;
+
+	return 0;
+      }
+  }
+#endif
 
 #ifdef CDAUDIO_SUBCHANNEL_DATA
   memset(&cdsc_data, '\0', sizeof(cdsc_data));
