@@ -840,7 +840,7 @@ cddb_read_line(int sock, char *inbuffer, int len)
     inbuffer[index] = inchar;
   }
   
-  fprintf(stdout, "%*s\n", index, index, inbuffer); 
+  fprintf(stdout, "%*s\n", index, inbuffer); 
   return index;
 }
 
