@@ -1,6 +1,7 @@
 /*
 This is part of the audio CD player library
 Copyright (C)1998-99 Tony Arcieri
+Copyright (C) 2003 Fabrice Bauzac
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
@@ -46,8 +47,17 @@ struct __unprocessed_disc_data {
    struct __unprocessed_track_data data_track[MAX_TRACKS];
 };
 
-int data_format_input(struct disc_data *outdata, struct __unprocessed_disc_data *indata, int tracks);
-int data_format_output(struct __unprocessed_disc_data *outdata, struct disc_data *indata, int tracks);
+int data_format_input(struct disc_data *outdata,
+		      struct __unprocessed_disc_data *indata,
+		      int tracks);
+
+int data_format_output(struct __unprocessed_disc_data *outdata,
+		       struct disc_data *indata,
+		       int tracks);
+
+int cddb_mc_generate_new_entry(int cd_desc,
+			       struct disc_mc_data *data);
+
 unsigned long __internal_cddb_discid(struct disc_info disc);
 
 #endif   
