@@ -46,7 +46,9 @@ Applied Cryptography by Bruce Schneier
 extern char *cddb_message;
 
 /* cdindex-tweaked base64 encoder */
-int cdindex_encode64(unsigned char *outbuffer, unsigned char *inbuffer, int inlen, int outlen);
+int cdindex_encode64(unsigned char *outbuffer,
+		     unsigned char *inbuffer,
+		     int inlen, int outlen);
 
 #define SHA_BLOCKSIZE 64
 #define SHA_VERSION 1
@@ -90,12 +92,7 @@ struct sha_data {
 };
 
 static void
-#if __STDC__
 sha_init(struct sha_data *sha)
-#else
-sha_init(sha)
-   struct sha_data *sha;
-#endif
 {
    sha->digest[0] = 0x67452301L;
    sha->digest[1] = 0xefcdab89L;
@@ -108,12 +105,7 @@ sha_init(sha)
 }
 
 static void 
-#if __STDC__
 sha_transform(struct sha_data *sha)
-#else
-sha_transform(sha)
-   struct sha_data *sha;
-#endif
 {
    int i;
    unsigned char *dp;
@@ -196,14 +188,7 @@ sha_transform(sha)
 }
 
 static void 
-#if __STDC__
 sha_update(struct sha_data *sha, unsigned char *buffer, int count)
-#else
-sha_update(sha, buffer, count)
-   struct sha_data *sha;
-   unsigned char *buffer;
-   int count;
-#endif
 {
    int i;   
    unsigned long clo;
@@ -238,13 +223,7 @@ sha_update(sha, buffer, count)
 }
 
 static void 
-#if __STDC__
 sha_final(unsigned char digest[20], struct sha_data *sha)
-#else
-sha_final(digest, sha)
-   unsigned char digest[20];
-   struct sha_data *sha;
-#endif
 { 
    int count;
    unsigned long lo_bit_count, hi_bit_count;
@@ -254,11 +233,13 @@ sha_final(digest, sha)
    count = (int) ((lo_bit_count >> 3) & 0x3f);
    ((unsigned char *) sha->data)[count++] = 0x80;
    if (count > SHA_BLOCKSIZE - 8) {  
-      memset(((unsigned char *) sha->data) + count, 0, SHA_BLOCKSIZE - count);
+      memset(((unsigned char *) sha->data) + count,
+	     0, SHA_BLOCKSIZE - count);
       sha_transform(sha);
       memset((unsigned char *) sha->data, 0, SHA_BLOCKSIZE - 8);
    } else
-     memset(((unsigned char *) sha->data) + count, 0, SHA_BLOCKSIZE - 8 - count);
+     memset(((unsigned char *) sha->data) + count,
+	    0, SHA_BLOCKSIZE - 8 - count);
    
    sha->data[56] = (hi_bit_count >> 24) & 0xff;
    sha->data[57] = (hi_bit_count >> 16) & 0xff;
@@ -292,14 +273,7 @@ sha_final(digest, sha)
 }
 
 int
-#if __STDC__
 cdindex_direct_discid(struct disc_info disc, char *discid, int len)
-#else
-cdindex_direct_discid(disc, discid, len)
-   struct disc_info disc;
-   char *discid;
-   int len;
-#endif
 {
    int index;
    struct sha_data sha;
@@ -312,11 +286,13 @@ cdindex_direct_discid(disc, discid, len)
    sha_update(&sha, temp, strlen(temp));
    snprintf(temp, 9, "%02X", disc.disc_total_tracks);
    sha_update(&sha, temp, strlen(temp));
-   snprintf(temp, 9, "%08X", disc.disc_track[disc.disc_total_tracks].track_lba + 150);
+   snprintf(temp, 9, "%08X",
+	    disc.disc_track[disc.disc_total_tracks].track_lba + 150);
    sha_update(&sha, temp, strlen(temp));
    for(index = 0; index < 99; index++) {
       if(index < disc.disc_total_tracks)
-	snprintf(temp, 9, "%08X", disc.disc_track[index].track_lba + 150);
+	snprintf(temp, 9, "%08X",
+		 disc.disc_track[index].track_lba + 150);
       else
 	snprintf(temp, 9, "%08X", 0);
       sha_update(&sha, temp, strlen(temp));
@@ -326,14 +302,7 @@ cdindex_direct_discid(disc, discid, len)
 }
 
 int
-#if __STDC__
 __internal_cdindex_discid(struct disc_info disc, char *discid, int len)
-#else
-__internal_cdindex_discid(disc, discid, len)
-   struct disc_info disc;
-   char *discid;
-   int len;
-#endif
 {
    return cdindex_direct_discid(disc, discid, len);
 }
@@ -356,14 +325,7 @@ cdindex_discid(int cd_desc, char *discid, int len)
 }
 
 int
-#if __STDC__
 cdindex_read_line(int sock, char *inbuffer, int len)
-#else
-cdindex_read_line(sock, inbuffer, len)
-   int sock;
-   char *inbuffer;
-   int len;
-#endif
 {
    int index;
    char inchar;
@@ -382,15 +344,9 @@ cdindex_read_line(sock, inbuffer, len)
 }
 
 int
-#if __STDC__
-cdindex_connect_server(struct cddb_host host, struct cddb_server *proxy, char *http_string, int len)
-#else
-cdindex_connect_server(host, proxy, http_string, len)
-  struct cddb_host host;
-  struct cddb_server *proxy;
-  char *http_string;
-  int len
-#endif
+cdindex_connect_server(struct cddb_host host,
+		       struct cddb_server *proxy,
+		       char *http_string, int len)
 {
    int sock;
    
@@ -402,20 +358,16 @@ cdindex_connect_server(host, proxy, http_string, len)
 	return -1;
    }
    
-   snprintf(http_string, len, "GET http://%s:%d/%s", host.host_server.server_name, host.host_server.server_port, host.host_addressing);
+   snprintf(http_string, len, "GET http://%s:%d/%s",
+	    host.host_server.server_name,
+	    host.host_server.server_port,
+	    host.host_addressing);
       
    return sock;
 }
 
 void
-#if __STDC__
 strip_whitespace(char *outbuffer, char *inbuffer, int len)
-#else
-strip_whitespace(outbuffer, inbuffer, len)
-  char *outbuffer;
-  char *inbuffer;
-  int len;
-#endif
 {
    int index, outdex = 0, readwhite = 1;
    
@@ -447,13 +399,7 @@ strip_whitespace(outbuffer, inbuffer, len)
 }
    
 static void
-#if __STDC__
 cdindex_process_line(char *line, struct disc_data *data)
-#else
-cdindex_process_line(line, data)
-  char *line;
-  struct disc_data *data;
-#endif
 {
    char *var, *value;
    
@@ -477,21 +423,17 @@ cdindex_process_line(line, data)
 	strncpy(data->data_title, value, 256);
    else if(strcmp(var, "Tracks") == 0);
    else if(strncmp(var, "Track", 5) == 0)
-     strncpy(data->data_track[strtol((char *)var + 5, NULL, 10) - 1].track_name, value, 256);
+     strncpy(data->data_track[strtol((char *)var + 5, NULL, 10) - 1]
+	     .track_name, value, 256);
    else if(strncmp(var, "Artist", 6) == 0)
-     strncpy(data->data_track[strtol((char *)var + 6, NULL, 10) - 1].track_artist, value, 256);
+     strncpy(data->data_track[strtol((char *)var + 6, NULL, 10) - 1]
+	     .track_artist, value, 256);
 }
 
 int
-#if __STDC__
-cdindex_read(int cd_desc, int sock, struct disc_data *data, char *http_string)
-#else
-cdindex_read(cd_desc, sock, data, http_string)
-  int cd_desc;
-  int sock;
-  struct disc_data *data;
-  char *http_string;
-#endif
+cdindex_read(int cd_desc, int sock,
+	     struct disc_data *data,
+	     char *http_string)
 {
    struct cddb_host host;
    struct disc_info disc;
@@ -512,7 +454,8 @@ cdindex_read(cd_desc, sock, data, http_string)
    data->data_revision = 0;
    data->data_genre = CDDB_MISC;
    
-   snprintf(outbuffer, 512, "%s?id=%s HTTP/1.0\n\n", http_string, data->data_cdindex_id);
+   snprintf(outbuffer, 512, "%s?id=%s HTTP/1.0\n\n",
+	    http_string, data->data_cdindex_id);
    
    write(sock, outbuffer, strlen(outbuffer));
    
@@ -543,13 +486,7 @@ cdindex_read(cd_desc, sock, data, http_string)
 }
 
 int
-#if __STDC__
 cdindex_generate_new_entry(int cd_desc, struct disc_data *data)
-#else
-cdindex_generate_new_entry(cd_desc, data)
-  int cd_desc;
-  struct disc_data *data;
-#endif
 {  
    if(cddb_read_data(cd_desc, data) < 0)
      cddb_generate_unknown_entry(cd_desc, data);
@@ -558,13 +495,7 @@ cdindex_generate_new_entry(cd_desc, data)
 }
 
 int
-#if __STDC__
 cdindex_read_disc_data(int cd_desc, struct disc_data *data)
-#else
-cdindex_read_disc_data(cd_desc, data)
-  int cd_desc;
-  struct disc_data *data;
-#endif
 {
    FILE *cdindex_xml;
    int track;
@@ -600,7 +531,8 @@ cdindex_read_disc_data(cd_desc, data)
    if((data->data_id = __internal_cddb_discid(disc)) < 0)
      return -1;
    
-   if(__internal_cdindex_discid(disc, data->data_cdindex_id, CDINDEX_ID_SIZE) < 0)
+   if(__internal_cdindex_discid(disc, data->data_cdindex_id,
+				CDINDEX_ID_SIZE) < 0)
      return -1;
    
    data->data_revision = 0;
@@ -633,7 +565,8 @@ cdindex_read_disc_data(cd_desc, data)
       else if(strncmp(procbuffer, "<MultipleArtistCD>", 18) == 0) {
 	 data->data_artist_type = CDINDEX_MULTIPLE_ARTIST;
 	 strncpy(data->data_artist, "(various)", 256);
-      } else if(data->data_artist_type == CDINDEX_SINGLE_ARTIST && strncmp(procbuffer, "<Artist>", 8) == 0) {
+      } else if(data->data_artist_type == CDINDEX_SINGLE_ARTIST &&
+		strncmp(procbuffer, "<Artist>", 8) == 0) {
 	 strtok(procbuffer, ">");
 	 strncpy(inbuffer, strtok(NULL, ">"), 512);
 	 strncpy(data->data_artist, strtok(inbuffer, "<"), 256);
@@ -647,13 +580,15 @@ cdindex_read_disc_data(cd_desc, data)
 	 if(data->data_artist_type == CDINDEX_MULTIPLE_ARTIST) {
 	    strtok(procbuffer, ">");
 	    strncpy(inbuffer, strtok(NULL, ">"), 512);
-	    strncpy(data->data_track[track].track_artist, strtok(inbuffer, "<"), 256);
+	    strncpy(data->data_track[track].track_artist,
+		    strtok(inbuffer, "<"), 256);
 	    fgets(inbuffer, 512, cdindex_xml);
 	    strip_whitespace(procbuffer, inbuffer, 512);
 	 }
 	 strtok(procbuffer, ">");
 	 strncpy(inbuffer, strtok(NULL, ">"), 512);
-	 strncpy(data->data_track[track].track_name, strtok(inbuffer, "<"), 256);
+	 strncpy(data->data_track[track].track_name,
+		 strtok(inbuffer, "<"), 256);
       }
    }
    
@@ -663,13 +598,7 @@ cdindex_read_disc_data(cd_desc, data)
 }
 
 int
-#if __STDC__
 cdindex_write_data(int cd_desc, struct disc_data *data)
-#else
-cdindex_write_data(cd_desc, data)
-  int cd_desc;
-  struct disc_data *data;
-#endif
 {
    FILE *cdindex_xml;
    int tracks;
@@ -688,7 +617,8 @@ cdindex_write_data(cd_desc, data)
    if((data->data_id = __internal_cddb_discid(disc)) < 0)
      return -1;
    
-   if(__internal_cdindex_discid(disc, data->data_cdindex_id, CDINDEX_ID_SIZE) < 0)
+   if(__internal_cdindex_discid(disc, data->data_cdindex_id,
+				CDINDEX_ID_SIZE) < 0)
      return -1;
    
    snprintf(root_dir, 256, "%s/.cdindex", getenv("HOME"));
@@ -709,27 +639,37 @@ cdindex_write_data(cd_desc, data)
    if((cdindex_xml = fopen(file, "w")) == NULL)
      return -1;
    
-   fputs("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n", cdindex_xml);
-   fputs("<!DOCTYPE CDInfo SYSTEM \"http://www.freeamp.org/dtd/CDInfo.dtd\">\n\n", cdindex_xml);
+   fputs("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n",
+	 cdindex_xml);
+   fputs("<!DOCTYPE CDInfo SYSTEM "
+	 "\"http://www.freeamp.org/dtd/CDInfo.dtd\">\n\n",
+	 cdindex_xml);
    fputs("<CDInfo>\n\n", cdindex_xml);
    fprintf(cdindex_xml, "   <Title>%s</Title>\n", data->data_title);
-   fprintf(cdindex_xml, "   <NumTracks>%d</NumTracks>\n\n", disc.disc_total_tracks);
+   fprintf(cdindex_xml, "   <NumTracks>%d</NumTracks>\n\n",
+	   disc.disc_total_tracks);
    fputs("   <IdInfo>\n", cdindex_xml);
    fputs("      <DiskId>\n", cdindex_xml);
-   fprintf(cdindex_xml, "         <Id>%s</Id>\n", data->data_cdindex_id);
-   fprintf(cdindex_xml, "         <TOC First=\"%d\" Last=\"%d\">\n", disc.disc_first_track, disc.disc_total_tracks);
-   fprintf(cdindex_xml, "            <Offset Num=\"0\">%d</Offset>\n", disc.disc_track[disc.disc_total_tracks].track_lba);
+   fprintf(cdindex_xml, "         <Id>%s</Id>\n",
+	   data->data_cdindex_id);
+   fprintf(cdindex_xml, "         <TOC First=\"%d\" Last=\"%d\">\n",
+	   disc.disc_first_track, disc.disc_total_tracks);
+   fprintf(cdindex_xml, "            <Offset Num=\"0\">%d</Offset>\n",
+	   disc.disc_track[disc.disc_total_tracks].track_lba);
    for(tracks = 0; tracks < disc.disc_total_tracks; tracks++)
-     fprintf(cdindex_xml, "            <Offset Num=\"%d\">%d</Offset>\n", tracks + 1, disc.disc_track[tracks].track_lba);
+     fprintf(cdindex_xml, "            <Offset Num=\"%d\">%d</Offset>\n",
+	     tracks + 1, disc.disc_track[tracks].track_lba);
    fputs("         </TOC>\n", cdindex_xml);
    fputs("      </DiskId>\n", cdindex_xml);
    fputs("   </IdInfo>\n\n", cdindex_xml);
    if(strcmp(data->data_artist, "(various)") != 0) {
       fputs("   <SingleArtistCD>\n", cdindex_xml);
-      fprintf(cdindex_xml, "      <Artist>%s</Artist>\n", data->data_artist);
+      fprintf(cdindex_xml, "      <Artist>%s</Artist>\n",
+	      data->data_artist);
       for(tracks = 0; tracks < disc.disc_total_tracks; tracks++) {
 	 fprintf(cdindex_xml, "      <Track Num=\"%d\">\n", tracks + 1);
-	 fprintf(cdindex_xml, "         <Name>%s</Name>\n", data->data_track[tracks].track_name);
+	 fprintf(cdindex_xml, "         <Name>%s</Name>\n",
+		 data->data_track[tracks].track_name);
 	 fputs("      </Track>\n", cdindex_xml);
       }
       fputs("   </SingleArtistCD>\n\n", cdindex_xml);
@@ -737,8 +677,10 @@ cdindex_write_data(cd_desc, data)
       fputs("   <MultipleArtistCD>\n", cdindex_xml);
       for(tracks = 0; tracks < disc.disc_total_tracks; tracks++) {
 	 fprintf(cdindex_xml, "      <Track Num=\"%d\">\n", tracks + 1);
-	 fprintf(cdindex_xml, "         <Artist>%s</Artist>\n", data->data_track[tracks].track_artist);
-	 fprintf(cdindex_xml, "         <Name>%s</Name>\n", data->data_track[tracks].track_name);
+	 fprintf(cdindex_xml, "         <Artist>%s</Artist>\n",
+		 data->data_track[tracks].track_artist);
+	 fprintf(cdindex_xml, "         <Name>%s</Name>\n",
+		 data->data_track[tracks].track_name);
 	 fputs("      </Track>\n", cdindex_xml);
       }
       fputs("   </MultipleArtistCD>\n\n", cdindex_xml);
@@ -750,15 +692,7 @@ cdindex_write_data(cd_desc, data)
 }
 
 int
-#if __STDC__
 cdindex_mc_read(int cd_desc, int sock, struct disc_mc_data *data, char *http_string)
-#else
-cdindex_mc_read(cd_desc, sock, data, http_string)
-   int cd_desc;
-   int sock;
-   struct disc_mc_data *data;
-   char *http_string;
-#endif
 {
    struct disc_data *indata;
    
@@ -786,13 +720,7 @@ cdindex_mc_read(cd_desc, sock, data, http_string)
 }
 
 int
-#if __STDC__
 cdindex_mc_read_disc_data(int cd_desc, struct disc_mc_data *data)
-#else
-cdindex_mc_read_disc_data(cd_desc, data)
-   int cd_desc;
-   struct disc_mc_data *data;
-#endif
 {
    struct disc_data *indata;
    
@@ -820,13 +748,7 @@ cdindex_mc_read_disc_data(cd_desc, data)
 }
 
 int
-#if __STDC__
 cdindex_mc_write_disc_data(int cd_desc, struct disc_mc_data *data)
-#else
-cdindex_mc_write_disc_data(cd_desc, data)
-   int cd_desc;
-   struct disc_mc_data *data;
-#endif
 {
    struct disc_data *outdata;
    
@@ -848,25 +770,13 @@ cdindex_mc_write_disc_data(cd_desc, data)
 }
 
 int
-#if __STDC__
 cdindex_mc_generate_new_entry(int cd_desc, struct disc_mc_data *data)
-#else
-cdindex_mc_generate_new_entry(cd_desc, data)
-   int cd_desc;
-   struct disc_mc_data *data;
-#endif
 {
    return cddb_mc_generate_new_entry(cd_desc, data);
 }
 
 int
-#if __STDC__
 cdindex_stat_disc_data(int cd_desc, struct cddb_entry *entry)
-#else
-cdindex_stat_disc_data(cd_desc, entry)
-  int cd_desc;
-  struct cddb_entry *entry;
-#endif
 {
    struct disc_info disc;
    struct stat st;
@@ -883,7 +793,8 @@ cdindex_stat_disc_data(cd_desc, entry)
    if((entry->entry_id = __internal_cddb_discid(disc)) < 0)
      return -1;
    
-   if(__internal_cdindex_discid(disc, entry->entry_cdindex_id, CDINDEX_ID_SIZE) < 0)
+   if(__internal_cdindex_discid(disc, entry->entry_cdindex_id,
+				CDINDEX_ID_SIZE) < 0)
      return -1;
    
    snprintf(root_dir, 256, "%s/.cdindex", getenv("HOME"));
@@ -918,14 +829,8 @@ cdindex_stat_disc_data(cd_desc, entry)
 }
 
 int
-#if __STDC__
-cdindex_http_submit(int cd_desc, struct cddb_host host, struct cddb_server *proxy)
-#else
-cdindex_http_submit(cd_desc, host, proxy)
-  int cd_desc;
-  struct cddb_host host;
-  struct cddb_server *proxy;
-#endif
+cdindex_http_submit(int cd_desc, struct cddb_host host,
+		    struct cddb_server *proxy)
 {
    FILE *cdindex_entry;
    int sock, token[3];
@@ -957,7 +862,10 @@ cdindex_http_submit(cd_desc, host, proxy)
 	 strncpy(cddb_message, strerror(errno), 256);
 	 return -1;
       }
-      snprintf(outbuffer, 512, "POST http://%s:%d/%s HTTP/1.0\n", host.host_server.server_name, host.host_server.server_port, CDINDEX_SUBMIT_CGI);
+      snprintf(outbuffer, 512, "POST http://%s:%d/%s HTTP/1.0\n",
+	       host.host_server.server_name,
+	       host.host_server.server_port,
+	       CDINDEX_SUBMIT_CGI);
    } else {
       if((sock = cddb_connect(&host.host_server)) < 0) {
 	 strncpy(cddb_message, strerror(errno), 256);
@@ -970,10 +878,12 @@ cdindex_http_submit(cd_desc, host, proxy)
    strncpy(outbuffer, "Content-Type: text/plain\n", 512);
    write(sock, outbuffer, strlen(outbuffer));
    
-   snprintf(cdindex_file, 512, "%s/.cdindex/%s", getenv("HOME"), entry.entry_cdindex_id);
+   snprintf(cdindex_file, 512, "%s/.cdindex/%s",
+	    getenv("HOME"), entry.entry_cdindex_id);
    stat(cdindex_file, &st);
    
-   snprintf(outbuffer, 512, "Content-Length: %d\n\r\n", (int) st.st_size + 1);
+   snprintf(outbuffer, 512, "Content-Length: %d\n\r\n",
+	    (int) st.st_size + 1);
    write(sock, outbuffer, strlen(outbuffer));
    
    cdindex_entry = fopen(cdindex_file, "r");
